/*
   Program to
        Monitor Smoke Alarm
        Activate Smoke Alarm Remote Buzzer


    Hardware Schematig and assembly Instructions for this code is here:
    http://Tek4um.com/smokeAlarm



   kg 05 May 2021 v1




   karl grabe Tek4um.com 2021 www.tek4um.com
  Please do not distibute. For personal use only.
*/


#define SMOKE_ALARM_INPUT_PIN 2    // connect to R3 (see circuit diagram)
#define BUZZER_OUTPUT_PIN 3   // connect to R4
#define SMOKE_ALARM_LED_STATUS 4   // on if Smoke Alarm input is active
#define SMOKE_ALARM_TEST_BUTTON 5  // for testing
#define HARDWARE_SERIAL_BAUD 115200
#define On true
#define Off false
#define TEST_TIME_DURATION 1000             // Time duration in ms to sound buzzer and status led for testing



void setup() {
  pinMode(SMOKE_ALARM_INPUT_PIN, INPUT);    // Connected to the modified Smoke Alarm
  pinMode(BUZZER_OUTPUT_PIN, OUTPUT);  // Connected to the Remote Buzzer, active LOW
  pinMode(LED_BUILTIN, OUTPUT);
  pinMode(SMOKE_ALARM_LED_STATUS, OUTPUT);         // active HIGH
  pinMode(SMOKE_ALARM_TEST_BUTTON, INPUT_PULLUP);  // active LOW





  Serial.begin(HARDWARE_SERIAL_BAUD);
  delay(500);
  Serial.println(F("Monitoring Smoke Alarm... "));


  // Test: Turn on the remote buzzer & Status LED briefly on startup
  setBuzzer (On);
  setStatusLED(On);


  delay(TEST_TIME_DURATION);
  
  setBuzzer (Off);
  setStatusLED(Off);;
}


void loop() {
  boolean testButtonState = !digitalRead(SMOKE_ALARM_TEST_BUTTON);  // read the test button, active LOW so invert it
  if (testButtonState) {
    setStatusLED(On);    // if the test button is presses, turn on transistor Q1 to sound the buzzer
    setBuzzer (On);
    delay (TEST_TIME_DURATION);
    setStatusLED(Off);    
    setBuzzer (Off); 
  }


  // Check if the smoke alarm is triggered, print it's state to serial monitor
  
  boolean smokeAlarmState = digitalRead(SMOKE_ALARM_INPUT_PIN);  // true: alarm is on so it's triggered (e.g. Fire!!)
 
 if (smokeAlarmState) { 
  String AlarmStateText = smokeAlarmState ? "On" : "Off";        // get text of smoke alarm state, true: On, false: Off
  Serial.print(F("Smoke Alarms is: "));
  Serial.println(AlarmStateText);
  setStatusLED(smokeAlarmState); // status led is on when smoke alarm is on
  return;
}


// add background timer to flash LED
  delay(100);  // delay before repeating messages
  flashStatusLED ();         // show program is running
  delay (100);
}




void setBuzzer (boolean state){
  digitalWrite(BUZZER_OUTPUT_PIN, !state); //  active low
}


void setStatusLED(boolean state) {
  digitalWrite(SMOKE_ALARM_LED_STATUS, state);  
}


void flashStatusLED(){
    digitalWrite(SMOKE_ALARM_LED_STATUS, !digitalRead(SMOKE_ALARM_LED_STATUS));
}

